/*
*            Copyright (c) 1998-2000 by NETsilicon Inc.
*
*  This software is copyrighted by and is the sole property of
*  NETsilicon.  All rights, title, ownership, or other interests
*  in the software remain the property of NETsilicon.  This
*  software may only be used in accordance with the corresponding
*  license agreement.  Any unauthorized use, duplication, transmission,
*  distribution, or disclosure of this software is expressly forbidden.
*
*  This Copyright notice may not be removed or modified without prior
*  written consent of NETsilicon.
*
*  NETsilicon, reserves the right to modify this software
*  without notice.
*
*  NETsilicon
*  411 Waverley Oaks Road                  USA 781.647.1234
*  Suite 227                               http://www.netsilicon.com
*  Waltham, MA 02452                       AmericaSales@netsilicon.com
*
*************************************************************************
*  $Name: Fusion 5.5 Beta 5 $
*  $Date:   Aug 15 2001 09:40:30  $
*  $Source: F:/psisrc/sntp/incl/rcs/sntpapi.h $
*  $Revision:   1.0  $
**************************************************************************
*  File Description:
*           SNTP Client API definitions.
*
**************************************************************************/
#ifndef _SNTP_API_

#define _SNTP_API_


/* SNTP critical section macro defaults */

#ifndef USE_SNTP_CRITICAL
#define USE_SNTP_CRITICAL int sntp_level
#endif

#ifndef SNTP_CRITICAL
#define SNTP_CRITICAL   sntp_level = os_critical()
#endif

#ifndef SNTP_NORMAL
#define SNTP_NORMAL     os_normal (sntp_level)
#endif

#define u32 unsigned long

/* structure used by fns_sntp_get_time and fns_sntp_set_time */

typedef struct {
    int hour;
    int minute;
    int second;
    int month;
    int day;
    int year;
                } SNTP_TIME;

/* sntpcli.c */
extern int fns_sntp_client_terminate (void);
extern int fns_sntp_client_configure (int mode,
                                     int options,
                                     void (*p_callback_function)(u32 offset[2], u32 time[2]),
                                     u32 recv_poll_rate,
                                     u32 query_poll_rate,
                                     char *p_server);

/* sntpsrv.c */
extern void fns_sntp_server (void);
extern int  fns_sntp_server_terminate (void);
extern int  fns_sntp_server_configure (int mode,
                                      u32 poll_rate,
                                      char *p_broadcast);

/* sntpclk.c */
extern void fns_sntp_subtract64(u32 *p_t1, u32 *p_t2, u32 *p_t3);
extern void fns_sntp_add64 (u32 *p_t1, u32 *p_t2, u32 *p_t3);
extern void fns_sntp_shift_right64 (u32 *p_t1, u32 *p_t2);

extern void fns_sntp_get_clock(u32 *p_ntp_time);
extern void fns_sntp_get_clock(u32 *p_ntp_time);
extern void fns_sntp_adjust_clock(u32 *p_adjustment);
extern void fns_sntp_get_time(u32 *p_ntp_time, SNTP_TIME *);
extern int  fns_sntp_set_time(u32 *p_ntp_time, SNTP_TIME *);
extern void fns_sntp_clock_configure(int timezone_correction);

extern void fns_sntp_clock_update(u32 update[2]);
extern void fns_sntp_time_milliseconds(u32 milliseconds, u32 *p_time);


/* Valid SNTP modes of operation */
#define SNTP_MULTICAST      0
#define SNTP_UNICAST        1
#define SNTP_ANYCAST        2

/* Valid SNTP Client options */
#define SNTP_AUTO_ADJUST_TIME           1

/* SNTP Error Codes */
#define SNTP_NO_ERROR                   0
#define SNTP_ILLEGAL_MODE               1
#define SNTP_INVALID_ADDRESS            2
#define SNTP_CANNOT_OPEN_SOCKET         3
#define SNTP_CLIENT_NOT_RUNNING         4
#define SNTP_SERVER_NOT_RUNNING         5
#define SNTP_INVALID_TIME               6

/* SNTP Client Default Configuration */
#ifndef SNTP_DEFAULT_RECEIVE_POLL_RATE
            /* rate to poll for reception of SNTP message */
#define SNTP_DEFAULT_RECEIVE_POLL_RATE  (2L * MS_PER_TICK)       /* default receive poll rate */
#endif

#ifndef SNTP_DEFAULT_QUERY_POLL_RATE
            /* rate to query SNTP Server */
#define SNTP_DEFAULT_QUERY_POLL_RATE    (60L * 1000L) /* 60 sec. */
#endif

/* SNTP Server Default Configuration */
#ifndef SNTP_DEFAULT_SERVER_MODE
#define SNTP_DEFAULT_SERVER_MODE    SNTP_UNICAST
#endif

#ifndef SNTP_DEFAULT_SERVER_POLL_RATE
#define SNTP_DEFAULT_SERVER_POLL_RATE   (5L * 60L * 1000L)
#endif
#endif

